==> estateplat-common-1.2.3-20190419.005626-236-sources.jar: cn/gtmap/estateplat/model/server/core/GdTdQl.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/*
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0,2016/4/19.
 * @description 土地权利查询属性结构描述
 */
@Table(name = "gd_td_ql")
public class GdTdQl {
    @Id
    private String qlid;
    private String proid;
    private String tdzh;
    private String qlr;
    private String tdzl;
    private String djlx;
    private String zslx;
    private String djh;
    private String tdid;
    private String qlrzjh;//权利人证件号

    //增加冗余字段
    private String ywrzjh;//以为人证件号
    private String bdcdybh;//不动产单元编号
    private String iszx;//是否注销
    private String cqzhjc;//产权证号简称
    public String getYwrzjh() {
        return ywrzjh;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getTdzh() {
        return tdzh;
    }

    public void setTdzh(String tdzh) {
        this.tdzh = tdzh;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getTdzl() {
        return tdzl;
    }

    public void setTdzl(String tdzl) {
        this.tdzl = tdzl;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getZslx() {
        return zslx;
    }

    public void setZslx(String zslx) {
        this.zslx = zslx;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getTdid() {
        return tdid;
    }

    public void setTdid(String tdid) {
        this.tdid = tdid;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getIszx() {
        return iszx;
    }

    public void setIszx(String iszx) {
        this.iszx = iszx;
    }

    public String getCqzhjc() {
        return cqzhjc;
    }

    public void setCqzhjc(String cqzhjc) {
        this.cqzhjc = cqzhjc;
    }
}

==> estateplat-common-1.2.4-20211123.065434-940-sources.jar: cn/gtmap/estateplat/model/server/core/GdTdQl.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/*
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0,2016/4/19.
 * @description 土地权利查询属性结构描述
 */
@Table(name = "gd_td_ql")
public class GdTdQl {
    @Id
    private String qlid;
    private String proid;
    private String tdzh;
    private String qlr;
    private String tdzl;
    private String djlx;
    private String zslx;
    private String djh;
    private String tdid;
    private String qlrzjh;//权利人证件号

    //增加冗余字段
    private String ywrzjh;//以为人证件号
    private String bdcdybh;//不动产单元编号
    private String iszx;//是否注销
    private String cqzhjc;//产权证号简称
    private String xzcfbh; //限制查封编号
    public String getYwrzjh() {
        return ywrzjh;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getTdzh() {
        return tdzh;
    }

    public void setTdzh(String tdzh) {
        this.tdzh = tdzh;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getTdzl() {
        return tdzl;
    }

    public void setTdzl(String tdzl) {
        this.tdzl = tdzl;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getZslx() {
        return zslx;
    }

    public void setZslx(String zslx) {
        this.zslx = zslx;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getTdid() {
        return tdid;
    }

    public void setTdid(String tdid) {
        this.tdid = tdid;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getIszx() {
        return iszx;
    }

    public void setIszx(String iszx) {
        this.iszx = iszx;
    }

    public String getCqzhjc() {
        return cqzhjc;
    }

    public void setCqzhjc(String cqzhjc) {
        this.cqzhjc = cqzhjc;
    }

    public String getXzcfbh() {
        return xzcfbh;
    }

    public void setXzcfbh(String xzcfbh) {
        this.xzcfbh = xzcfbh;
    }
}
